"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/app/module/v1alpha1/module.proto\x12\x1acosmos.app.module.v1alpha1\x1a cosmos/app/v1alpha1/module.proto"I\n\x06Module:?\xba\xc0\x96\xda\x019\n github.com/cosmos/cosmos-sdk/app\x12\x15\n\x13cosmos.app.v1alpha1b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.app.module.v1alpha1.module_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _MODULE._options = None
    _MODULE._serialized_options = b'\xba\xc0\x96\xda\x019\n github.com/cosmos/cosmos-sdk/app\x12\x15\n\x13cosmos.app.v1alpha1'
    _MODULE._serialized_start = 105
    _MODULE._serialized_end = 178